summaryrefslogtreecommitdiff
path: root/main/snprintf.h
diff options
context:
space:
mode:
authorVeres Lajos <vlajos@gmail.com>2013-07-13 13:37:04 +0100
committerStanislav Malyshev <stas@php.net>2013-07-15 00:19:49 -0700
commit1b06e0be96774eeb59a59b80476213a8b98a8fdc (patch)
treec4fe348b1f1ca872dbf58a6c643534e92be25715 /main/snprintf.h
parentd17e8ac32fe1f4bbf92c4bac1826d83d8372df95 (diff)
downloadphp-git-1b06e0be96774eeb59a59b80476213a8b98a8fdc.tar.gz
typo fixes
Diffstat (limited to 'main/snprintf.h')
-rw-r--r--main/snprintf.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/main/snprintf.h b/main/snprintf.h
index de03542cad..f4ed4d234d 100644
--- a/main/snprintf.h
+++ b/main/snprintf.h
@@ -27,7 +27,7 @@ sprintf offers the ability to make a lot of failures since it does not know
the size of the buffer it uses. Therefore usage of sprintf often
results in possible entries for buffer overrun attacks. So please
use this version only if you are sure the call is safe. sprintf
- allways terminstes the buffer it writes to.
+ always terminstes the buffer it writes to.
snprintf knows the buffers size and will not write behind it. But you will
have to use either a static buffer or allocate a dynamic buffer
@@ -48,7 +48,7 @@ spprintf is the dynamical version of snprintf. It allocates the buffer in size
snprintf and offers possible memory leakes if you miss freeing the
buffer allocated by the function. Therfore this function should be
used where either no maximum is known or the maximum is much bigger
- than normal size required. spprintf allways terminates the buffer.
+ than normal size required. spprintf always terminates the buffer.
Example:
@@ -60,7 +60,7 @@ Example:
sprintf(buffer, "test"); | snprintf(buffer, MAX, "test"); | spprintf(&buffer, MAX, "text");
| | if (!buffer)
| | return OUT_OF_MEMORY
// sprintf allways terminates | // manual termination of | // spprintf allays terminates buffer
// buffer | // buffer *IS* required |
| buffer[MAX-1] = 0; |
action_with_buffer(buffer); | action_with_buffer(buffer); | action_with_buffer(buffer);
@@ -60,7 +60,7 @@ Example:
| | if (!buffer)
| | return OUT_OF_MEMORY
- // sprintf allways terminates | // manual termination of | // spprintf allays terminates buffer
+ // sprintf always terminates | // manual termination of | // spprintf allays terminates buffer
// buffer | // buffer *IS* required |
| buffer[MAX-1] = 0; |